@@ -1,4 +1,4 @@
-/* $Id: SUPDrvInternal.h 102142 2015-08-17 11:54:27Z bird $ */
+/* $Id: SUPDrvInternal.h 103607 2015-10-22 13:32:47Z bird $ */
 /** @file
  * VirtualBox Support Driver - Internal header.
  */
@@ -230,12 +230,19 @@
 # undef SUPDRV_WITH_MSR_PROBER
 #endif
 
-#if 1
-/**  Use a dedicated kernel thread to service TSC-delta measurement requests.
- *   @todo Test on servers with many CPUs and sockets. */
-#define SUPDRV_USE_TSC_DELTA_THREAD
+#ifdef DOXYGEN_RUNNING
+# define SUPDRV_WITH_MSR_PROBER
+# define SUPDRV_WITHOUT_MSR_PROBER
 #endif
 
+#if 1
+/** @def SUPDRV_USE_TSC_DELTA_THREAD
+ * Use a dedicated kernel thread to service TSC-delta measurement requests.
+ * @todo Test on servers with many CPUs and sockets. */
+# define SUPDRV_USE_TSC_DELTA_THREAD
+#endif
+
+
 /*******************************************************************************
 *   Structures and Typedefs                                                    *
 *******************************************************************************/
